@@ -66,8 +66,9 @@ typedef struct {
 
   guint merge_id;
 
+  guint is_actor         : 1;
+  guint is_stage         : 1;
   guint is_stage_default : 1;
-  guint is_toplevel      : 1;
   guint has_unresolved   : 1;
   guint is_unmerged      : 1;
 } ObjectInfo;
